@@ -6,6 +6,7 @@
 
 #include "GpxEngine.h"
 #include "GeoDataModel.h"
+#include "Logging.h"
 
 #include "debugMode.h"
 
@@ -20,10 +21,8 @@
 #include <QJsonDocument>
 #include <QStandardPaths>
 #include <QFile>
-
-#ifdef DEBUG_MODE
+#include <QLoggingCategory>
 #include <QTimeZone>
-#endif // DEBUG_MODE
 
 // C++ includes
 #include <cmath>
@@ -50,6 +49,10 @@ GpxEngine::GpxEngine(QObject *parent, GeoDataModel *geoDataModel)
             m_timezoneMapWidth = m_timezoneMap.size().width();
             m_timezoneMapHeight = m_timezoneMap.size().height();
         }
+        qCDebug(KGeoTagLog) << "Loaded the timezones map from" << timezoneMapFile;
+    } else {
+        // This should not happen
+        qCDebug(KGeoTagLog) << "Failed to load the timezones map file!";
     }
 
     // Load the color-timezone mapping
@@ -62,15 +65,20 @@ GpxEngine::GpxEngine(QObject *parent, GeoDataModel *geoDataModel)
             jsonData.close();
             m_timezoneMapping = jsonDocument.object();
         }
+        qCDebug(KGeoTagLog) << "Loaded the timezone mapping data from" << timezoneMappingFile;
+    } else {
+        // This should not happen
+        qCDebug(KGeoTagLog) << "Failed to load the timezone mapping data file!";
     }
 
-#ifdef DEBUG_MODE
     // Check if all listed timezones are valid
 
     if (! m_timezoneMapping.isEmpty()) {
         const auto allTimeZones = QTimeZone::availableTimeZoneIds();
         const auto keys = m_timezoneMapping.keys();
+
         QVector<QByteArray> invalidIds;
+
         for (const auto &key : keys) {
             const auto timeZoneId = m_timezoneMapping.value(key).toString().toUtf8();
             if (! allTimeZones.contains(timeZoneId)) {
@@ -78,18 +86,21 @@ GpxEngine::GpxEngine(QObject *parent, GeoDataModel *geoDataModel)
             }
         }
 
+        qCDebug(KGeoTagLog) << "Processed" << m_timezoneMapping.count() << "timezone IDs";
+
         if (invalidIds.count() > 0) {
-            qDebug() << "Found" << invalidIds.count() << "invalid timezone ID(s)!";
-            qDebug() << "    The following IDs are not represented in "
-                     << "QTimeZone::availableTimeZoneIds():";
+            qCWarning(KGeoTagLog) << "Found" << invalidIds.count() << "unusable timezone ID(s)!";
+            qCWarning(KGeoTagLog) << "    The following IDs are not represented in "
+                                  << "QTimeZone::availableTimeZoneIds():";
             for (const auto &id : invalidIds) {
-                qDebug() << "   " << id;
+                qCWarning(KGeoTagLog) << "   " << id;
             }
-        } else {
-            qDebug() << "Successfully loaded" << m_timezoneMapping.count() << "timezone IDs";
         }
+
+    } else {
+        // This should not happen
+        qCWarning(KGeoTagLog) << "Could not load any timezone IDs!";
     }
-#endif // DEBUG_MODE
 }
 
 GpxEngine::LoadInfo GpxEngine::load(const QString &path)
