@@ -1,7 +1,6 @@
-/* SPDX-FileCopyrightText: 2020-2021 Tobias Leupold <tobias.leupold@gmx.de>
-
-   SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-KDE-Accepted-GPL
-*/
+// SPDX-FileCopyrightText: 2020-2022 Tobias Leupold <tl at stonemx dot de>
+//
+// SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #ifndef GPXENGINE_H
 #define GPXENGINE_H
@@ -64,6 +63,8 @@ private: // Variables
     int m_maximumInterpolationDistance;
 
     QImage m_timezoneMap;
+    double m_timezoneMapWidth = 0.0;
+    double m_timezoneMapHeight = 0.0;
     QJsonObject m_timezoneMapping;
     QByteArray m_lastDetectedTimeZoneId;
 
