@@ -26,6 +26,7 @@
 #include "TracksListView.h"
 #include "GeoDataModel.h"
 #include "TrackWalker.h"
+#include "Logging.h"
 
 // KDE includes
 #include <KActionCollection>
@@ -51,6 +52,7 @@
 #include <QCloseEvent>
 #include <QAbstractButton>
 #include <QVBoxLayout>
+#include <QLoggingCategory>
 
 // C++ includes
 #include <functional>
@@ -452,6 +454,9 @@ void MainWindow::addFiles(const QStringList &files)
                                  "*.tif *.tiff "
                                  "*.ora "
                                  "*.kra "
+                                 "*.cr2 "
+                                 "*.nef "
+                                 "*.dng "
                                  "*.gpx "
                              ");; All files (*)"));
     } else {
@@ -725,8 +730,9 @@ void MainWindow::addGpx(const QVector<QString> &paths)
                 QMessageBox::warning(this, i18n("Setting the detected timezone failed"),
                     i18n("<p>The presumably correct timezone \"%1\" has been detected from the "
                          "loaded GPX file, but could not be set. This should not happen!</p>"
-                         "<p>Please file a bug report about this, including the used version of "
-                         "KGeoTag and Qt!</p>"
+                         "<p>Please file a bug report about this, including the installed versions "
+                         "of KGeoTag and your system's timezone data (the package owning "
+                         "<kbd>/usr/share/zoneinfo</kbd>).</p>"
                          "<p>You can adjust the timezone setting manually on the \"Fix time "
                          "drift\" page.</p>",
                          QString::fromLatin1(id)));
@@ -1244,7 +1250,7 @@ void MainWindow::saveChanges(const QVector<QString> &files)
 
     QApplication::setOverrideCursor(Qt::WaitCursor);
 
-    const auto writeMode = s_writeModeMap.value(m_settings->writeMode());
+    auto writeMode = s_writeModeMap.value(m_settings->writeMode());
     const bool createBackups =
         writeMode != KExiv2Iface::KExiv2::MetadataWritingMode::WRITETOSIDECARONLY
         && m_settings->createBackups();
@@ -1379,6 +1385,17 @@ void MainWindow::saveChanges(const QVector<QString> &files)
 
         // Save the changes
 
+        if (MimeHelper::isRawImage(path)
+            && writeMode != KExiv2Iface::KExiv2::MetadataWritingMode::WRITETOSIDECARONLY) {
+
+            if (m_settings->allowWriteRawFiles()) {
+                exif.setWriteRawFiles(true);
+            } else {
+                qCDebug(KGeoTagLog) << "Falling back to write XMP sidecar file for" << path;
+                writeMode = KExiv2Iface::KExiv2::MetadataWritingMode::WRITETOSIDECARONLY;
+            }
+        }
+
         exif.setMetadataWritingMode(writeMode);
 
         while (! exif.applyChanges()) {
@@ -1551,7 +1568,7 @@ void MainWindow::elevationProcessed(ElevationEngine::Target target, const QVecto
         m_imagesModel->setElevation(path, elevation);
     }
 
-    emit checkUpdatePreview(paths);
+    Q_EMIT checkUpdatePreview(paths);
     QApplication::restoreOverrideCursor();
 }
 
