@@ -43,7 +43,7 @@ public:
 protected:
     void closeEvent(QCloseEvent *event) override;
 
-private slots:
+private Q_SLOTS:
     void updateImagesListsMode();
     void setDefaultDockArrangement();
 
