@@ -23,6 +23,8 @@ import tempfile
 from pathlib import Path
 from typing import List
 import re
+from hashlib import sha1
+import sys
 
 from PyQt5.QtCore import QSize, Qt
 from PyQt5.QtGui import QColor
@@ -38,6 +40,7 @@ from qgis.core import (
 )
 from qgis.PyQt.QtCore import QEventLoop
 
+# Initialize QGis
 qgs = QgsApplication([], False)
 QgsApplication.setPrefixPath("/usr", True)
 QgsApplication.initQgis()
@@ -65,7 +68,7 @@ def stylize_map(layer: QgsVectorLayer) -> [List[str], List[str]]:
     timezone_colors = []
     features = layer.getFeatures()
     categories = []
-    currentColor = 0
+    usedColors = []
 
     for tz in timezones:
         # Modify the Etc timezones to match the Qt format
@@ -81,16 +84,24 @@ def stylize_map(layer: QgsVectorLayer) -> [List[str], List[str]]:
         elif tz == "Etc/GMT":
             qt_tz = "UTC+00:00"
 
-        # Generate a consecutive color for each timezone
-        currentColor += 25000
-        r = (currentColor >> 16) & 255
-        g = (currentColor >> 8 ) & 255
-        b = (currentColor      ) & 255
+        # Derive a color from the timezone's name
+
+        hex = sha1(qt_tz.encode("utf-8")).hexdigest()[0:6]
+        if hex in usedColors:
+            # This is very unlikely if not impossible to happen, but who knows?!
+            print("Timezone {} caused a color collision! Please review this script!".format(qt_tz))
+            sys.exit(1)
+        usedColors.append(hex)
+
+        rh = hex[0:2]
+        gh = hex[2:4]
+        bh = hex[4:6]
+
+        r = int(rh, 16)
+        g = int(gh, 16)
+        b = int(bh, 16)
 
         # Add it to the mapping
-        rh = hex(r)[2:]
-        gh = hex(g)[2:]
-        bh = hex(b)[2:]
         timezone_ids.append(qt_tz)
         timezone_colors.append(f"#{rh:0>2}{gh:0>2}{bh:0>2}")
 
@@ -164,22 +175,24 @@ def export_data(layer: QgsVectorLayer, timezone_ids: List[str], timezone_colors:
 
 def main():
     parser = argparse.ArgumentParser()
-    parser.add_argument("input-timezone-data",
-                        type=Path,
-                        help="The timezone data shapefile (.shp).")
+    parser.add_argument("--shapefile",
+                        type = Path,
+                        help = "The timezone data shapefile (.shp, defaults to "
+                               "combined-shapefile-with-oceans.shp)",
+                        default = "combined-shapefile-with-oceans.shp")
     parser.add_argument("--outdir",
-                        type=Path,
-                        help="The folder to place the output data files in (defaults to .).",
-                        default=".")
+                        type = Path,
+                        help = "The folder to place the output data files in (defaults to .)",
+                        default = ".")
     parser.add_argument("--height",
-                        type=int,
-                        help="The height of the output image. Should be an even number. "
-                             "Defaults to 2000.",
-                        default=2000)
+                        type = int,
+                        help = "The height of the output image. Should be an even number "
+                               "(defaults to 2000)",
+                        default = 2000)
     args = vars(parser.parse_args())
 
-    print(f"Opening data file: {args['input-timezone-data'].absolute().resolve()}")
-    layer = QgsVectorLayer(str(args["input-timezone-data"]))
+    print(f"Opening data file: {args['shapefile'].absolute().resolve()}")
+    layer = QgsVectorLayer(str(args["shapefile"]))
     timezone_ids, timezone_colors = stylize_map(layer)
     export_data(layer, timezone_ids, timezone_colors, args["outdir"], args["height"])
 
